#!/bin/bash
#
# 08/10/2013 Updated to add detection for tomcat verstion (RA)
# 14/02/2014 Updated to copy cache.xml from old location to new config dir (RA)

source /backups/patch/settings.sh
initialise() {
 if test -f /etc/rc.d/init.d/tomcat5; then
  TOMCAT=tomcat5; fi
 if test -f /etc/rc.d/init.d/tomcat; then
  TOMCAT=tomcat; fi
 if test ! $TOMCAT; then
  echo "Unable to detect the vesion of tomcat installed."
  echo "Exiting..."
  exit; fi
}


heading() {
 clear
 echo "${inv} Swivel Maintenance (c) $COPYRIGHT_YEAR${nor}
            ${inv}$PINSAFE_TYPE${nor}"
 echo
 echo $1
 echo
}

s_heading() {
 clear
 echo "${inv} Swivel Maintenance (c) $COPYRIGHT_YEAR${nor}
            ${inv}$PINSAFE_TYPE${nor}"
 echo
}

yorn() {
 echo
 echo -n "Are you sure? (Yes/No): "
 read yn
 check_ans $1 $yn
}

check_ans() {
 if test ! $2; then
  $1; fi
 if test ! $2 = "Yes" && test ! $2 = "yes" && test ! $2 = "y" && test ! $2 = "Y" ; then
  $1; fi
}

get_patch_ver() {
 PATCH_VER_ORIG=`grep APPLIANCE_PATCH_VER /etc/pinsafe.conf|cut -d\= -f2`
 patch_ver_new=`echo $PATCH_VER|cut -d\. -f3`
 patch_ver_existing=`grep APPLIANCE_PATCH_VER /etc/pinsafe.conf|cut -d\. -f3`
}

update_patch_ver() {
 sed -i "s/APPLIANCE_PATCH_VER=$PATCH_VER_ORIG/APPLIANCE_PATCH_VER=$PATCH_VER/g" /etc/pinsafe.conf
}

test_patch_ver(){
 p1=`expr $patch_ver_existing + 1`

 if test $patch_ver_new -le $patch_ver_existing; then
  echo "This patch has already been applied."
  echo
  echo "   Current patch level of appliance: $PATCH_VER_ORIG"
  echo "   Patch version: $PATCH_VER"
  echo
  read -p "Press Return to exit"
  exit; fi

 if test $p1 -gt $patch_ver_new; then
  echo "The applaince patch version is newer than the patch you are trying to apply."
  echo
  echo "   Current patch level of appliance: $PATCH_VER_ORIG"
  echo "   Patch version: $PATCH_VER"
  echo
  read -p "Press Return to exit"
  exit; fi

 if test $p1 -lt $patch_ver_new; then
  echo "Please apply the previous patches before applying this patch. Existing patch"
  echo "level is too low:"
  echo
  echo "   Current patch level of appliance: $PATCH_VER_ORIG"
  echo "   Patch version: $PATCH_VER"
  echo
  read -p "Press Return to exit"
  exit; fi
}

get_value() {
 VALUE=`grep ^$1= $PINSAFE_CONF | cut -d\= -f2`
 if test $VALUE; then
  echo "$1=$VALUE" >> $PINSAFE_CONF_NEW
 else
  echo "$1=$2" >> $PINSAFE_CONF_NEW
 fi
}

cmi_version() {
 CMI_VER=`grep ^version= /usr/local/bin/smenu|cut -d\" -f2`
 CMI_VER=$(echo $CMI_VER |awk -F\. '{print $1$2}')
 CMI_REQUIRED=$(echo $CMI_REQUIRED |awk -F\. '{print $1$2}')
}

cmi_version_error() {
 echo
 echo "The appliance version requires upgrading before updating PINsafe."
 echo
}

java_version() {
 JAVA_VER=$(java -version 2>&1 | sed 's/java version "\(.*\)\.\(.*\)\..*"/\1\2/; 1q')
}

java_version_error() {
 echo
 echo "The version of JAVA installed on the appliance required upgrading before the"
 echo "installation can continue. Please install the latest appliance patch"
 echo
}

check_running() {
 if test "`ps -eaf|grep $2|egrep -v "UID|grep|mysqld_safe|alert.d" 2>/dev/null`"; then
  if test ! -f $LOCK/$1; then
   touch $LOCK/$1; fi
 else
  if test -f $LOCK/$1; then
   rm -f $LOCK/$1; fi
 fi

 if test -f $LOCK/$1; then
  value="Running"
 else
  value="Stopped"
 fi
}

show_dots() {
 i=0
 while test $i -lt $1; do
  echo -n "."
  sleep 1 
  ((i = i + 1))
 done
}

service_sands_tomcat() {
 nohup service $TOMCAT $1 > /dev/null 2>&1 &
 echo -n "Tomcat: $1"
 show_dots 4
}

service_sands() {
 service $1 $2
}

warning() {
# Check the patch should run before doing anything
 yorn exit

 heading "Upgrading Swivel"
 echo "Continuing will apply patch ${inv}$PATCH_VER${nor}. It is suggested that the system is"
 echo "not authenticating users whilst the patch is applied."
}

# Create update routine. Use Standard calls above.

commands() {
 java_version
 cmi_version
 if test $JAVA_VER -ge $JAVA_REQUIRED; then
  if test $CMI_VER; then
   if test $CMI_VER -ge $CMI_REQUIRED; then
    install_swivel
    set_values
   else
    cmi_version_error
    echo; read -p "Press Return to continue" yn
    exit
   fi
  else
   cmi_version_error
   echo; read -p "Press Return to continue" yn
   exit
  fi
 else
  java_version_error
  echo; read -p "Press Return to continue" yn
  exit
 fi
}

set_values() {
 echo "PINSAFE_PATCH_VER=2.0.7" > $PINSAFE_CONF_NEW
 cat $PINSAFE_CONF | grep -v ^PINSAFE_PATCH_VER >> $PINSAFE_CONF_NEW
 cat $PINSAFE_CONF_NEW > $PINSAFE_CONF
 rm $PINSAFE_CONF_NEW
}

install_swivel() {
 check_running $TOMCAT tomcat
 if test $value = "Running"; then
  echo "Stopping Tomcat and Swivel service"
  service_sands $TOMCAT stop
 fi
 
 echo "Creating new Swivel configuration dir."
 mkdir -p $SWIVEL
 chown -R swivel:swivel $SWIVEL
 
 echo "Creating backups of original configurations"
 if test -d $TOMCAT_PATH/webapps/pinsafe/WEB-INF/conf; then
  cp -rp $TOMCAT_PATH/webapps/pinsafe/WEB-INF/conf $SWIVEL; fi
 if test -d $TOMCAT_PATH/webapps/pinsafe/WEB-INF/data; then
  cp -rp $TOMCAT_PATH/webapps/pinsafe/WEB-INF/data $SWIVEL; fi
 if test -d $TOMCAT_PATH/webapps/pinsafe/WEB-INF/db; then
  cp -rp $TOMCAT_PATH/webapps/pinsafe/WEB-INF/db $SWIVEL; fi
 if test -d $TOMCAT_PATH/webapps/pinsafe/WEB-INF/logs; then
  cp -rp $TOMCAT_PATH/webapps/pinsafe/WEB-INF/logs $SWIVEL; fi
 if test -d $TOMCAT_PATH/webapps/pinsafe/WEB-INF/active-mq; then
  cp -rp $TOMCAT_PATH/webapps/pinsafe/WEB-INF/active-mq $SWIVEL; fi
 if test -d $TOMCAT_PATH/webapps/pinsafe/WEB-INF/reports; then
  cp -rp $TOMCAT_PATH/webapps/pinsafe/WEB-INF/reports $SWIVEL; fi
 if test -f $TOMCAT_PATH/webapps/pinsafe/WEB-INF/classes/cache.xml; then
  cp -rp $TOMCAT_PATH/webapps/pinsafe/WEB-INF/classes/cache.xml $SWIVEL/conf; fi

 echo "Creating backup of original PINsafe to /tmp"
 if test -d $TOMCAT_PATH/webapps/pinsafe; then
  cp -rp $TOMCAT_PATH/webapps/pinsafe /tmp; fi

 echo "Starting Tomcat and Swivel service"
 service_sands_tomcat start

 echo; echo "Removing old PINsafe instance"
 rm -f $TOMCAT_PATH/webapps/pinsafe.war
 sleep 10
 if test -d $TOMCAT_PATH/webapps/pinsafe; then
  rm -rf $TOMCAT_PATH/webapps/pinsafe; fi 

 echo; echo "Deploying new Swivel software"
 cp $PATCHBASE/pinsafe.war $TOMCAT_PATH/webapps 

 echo "Upgrade complete"
}


warning
initialise
commands
echo; read -p "Press Return to continue" yn
